"""Top-level package for autosbatch."""
from autosbatch.autosbatch import SlurmPool

__author__ = """Jianhua Wang"""
__email__ = 'jianhua.mert@gmail.com'
__version__ = '0.1.6'
